@@ -21,10 +21,13 @@ def finish(
     *, response: Response, query_str: str, should_print: bool, start_time: float
 ) -> dict:
     j = response.json()
-    print(
-        f"took: {(time.time() - start_time) * 1000}, "
-        f'took internal: {int(j["extensions"]["tracing"]["duration"]) / (10 ** 6)}'
-    )
+    try:
+        print(
+            f"took: {(time.time() - start_time) * 1000}, "
+            f'took internal: {int(j["extensions"]["tracing"]["duration"]) / (10 ** 6)}'
+        )
+    except Exception as e:
+        print(f"ERRORED with {e=} IN FINISH, {j=}")
     if should_print:
         print(f"{query_str=}, {j=}")
     check_for_errors(j)
