@@ -244,7 +244,7 @@ class Node(BaseModel):
         strict: bool = False,
         use_stale: bool = False,
     ) -> T.Optional[T.Union[NodeModel, T.Set[NodeModel]]]:
-        root_resolver = self.get_root_resolver()()
+        root_resolver = self.GQL.resolver()
         if not resolver:
             resolver = root_resolver.edges.__fields__[name].type_()
         if refresh:
